@@ -8,16 +8,17 @@ if [[ "$1" == "--kind" ]] || [[ "$1" == "-k" ]]; then
 fi
 
 sudo -E kubectl get pods -o wide
+sudo -E kubectl get deployments
 
 if [[ "$KUBE" == "minikube" ]]; then
   echo ::group::METRICS
-  sudo -E kubectl top pods
-  sudo -E kubectl describe node minikube
+  sudo -E kubectl top pods || true
+  sudo -E kubectl describe node minikube || true
   echo ::endgroup::
 fi
 
 echo ::group::OPERATOR_LOGS
-sudo -E kubectl logs -l app.kubernetes.io/name=pulp-operator -c manager --tail=10000
+sudo -E kubectl logs -l app.kubernetes.io/name=pulp-operator -c pulp-manager --tail=10000
 echo ::endgroup::
 
 echo ::group::PULP_API_LOGS
@@ -32,10 +33,6 @@ echo ::group::PULP_WORKER_LOGS
 sudo -E kubectl logs -l app.kubernetes.io/name=pulp-worker --tail=10000
 echo ::endgroup::
 
-echo ::group::PULP_RESOURCE_MANAGER_LOGS
-sudo -E kubectl logs -l app.kubernetes.io/name=pulp-resource-manager --tail=10000
-echo ::endgroup::
-
 echo ::group::PULP_WEB_LOGS
 sudo -E kubectl logs -l app.kubernetes.io/name=nginx --tail=10000
 echo ::endgroup::
